@@ -82,7 +82,6 @@ document.getElementById("passwordsTree").addEventListener(
   false);
 
 var spEditor = {
-  strBundle: null,
   prefs: Components.classes["@mozilla.org/preferences-service;1"].
          getService(Components.interfaces.nsIPrefService).
          getBranch("extensions.savedpasswordeditor."),
@@ -118,7 +117,7 @@ var spEditor = {
 
   mcbWrapper: function (method) {
     var myThis = this;
-    return function () method.apply(myThis, arguments);
+    return function () { return method.apply(myThis, arguments); };
   },
 
   showErrorAlert: function (e) {
@@ -128,9 +127,9 @@ var spEditor = {
       bag = prompt.QueryInterface(
         Components.interfaces.nsIWritablePropertyBag2);
     bag.setPropertyAsBool("allowTabModal", true);
-    prompt.alert(this.strBundle.getString("error"),
-                 this.strBundle.getFormattedString("badnewentry",
-                                                   [e.message]));
+    prompt.alert(this.genStrBundle.getString("error"),
+                 this.pmoStrBundle.getFormattedString("badnewentry",
+                                                      [e.message]));
   },
 
   SPE_WINDOW_NAME: "danieldawson:savedpasswordeditor",
@@ -162,7 +161,7 @@ var spEditor = {
 
   _mergeSignonProps: function (oldSignon, newProps) {
     var merged = {};
-    for (prop in newProps)
+    for (let prop in newProps)
       if (newProps[prop] === undefined)
         merged[prop] = oldSignon[prop];
       else
@@ -175,7 +174,7 @@ var spEditor = {
     var selections = gDataman.getTreeSelections(gPasswords.tree);
     if (selections.length == 0) return;
     var selSignons =
-      selections.map(function (el) gPasswords.displayedSignons[el]);
+      selections.map(el => gPasswords.displayedSignons[el]);
 
     function __finish (newSignon) {
       try {
@@ -233,7 +232,7 @@ var spEditor = {
     var selections = gDataman.getTreeSelections(gPasswords.tree);
     if (selections.length == 0) return;
     var selSignons =
-      selections.map(function (el) gPasswords.displayedSignons[el]);
+      selections.map(el => gPasswords.displayedSignons[el]);
 
     var curWin =
         Components.classes["@mozilla.org/appshell/window-mediator;1"].
